require 'uu/os/rest/dto'
require 'uu/os/uesuri'



module UU
  module ADK
    module App
      # App Attributes DTO.
      # @deprecated Use {UU::OS::AppMetaModel::AppMetaModelAttributes} instead.
      class AppAttributes < UU::OS::REST::DTO

        # Normalized UESURI of the app. Never null.
        attr_accessor :uri

        # Name of the app. Never null.
        attr_accessor :name

        # Code of the app. Never null.
        attr_accessor :code

        # Description of the app. Never null.
        attr_accessor :description
        
        # UESURI of appbox from which was the app created.
        attr_accessor :app_box_uri

        # URI of the app's container. Returns null if the organizational
        # unit is the root of a territory (therefore there is no superior folder, organizational
        # unit etc.).
        attr_accessor :location_uri

        # URI of the parent app. Returns null if the app
        # is the root of a territory (therefore there is no superior app).
        attr_accessor :organizational_unit_uri

        # URI of the company where the app is located.
        attr_accessor :company_uri

        # URI of the meta artifact. Never null.
        attr_accessor :meta_artifact_uri

        # URI of the competent role. Never null.
        attr_accessor :competent_role_uri

        # Artifact type. Always returns {@link UESArtifactType#ORGANIZATIONAL}.
        attr_accessor :artifact_type

        # Security level of the app. Never null.
        attr_accessor :security_level

        # Creation stamp of the app. Never null.
        attr_accessor :creation_stamp

        # Creation time of the app. Never null.
        attr_accessor :creation_time

        # Modification stamp of the app. Never null.
        attr_accessor :modification_stamp

        # Modification time of the app. Never null.
        attr_accessor :modification_time

        # Version of the app. Never null.
        attr_accessor :version

        # URI of the app's icon. When null is set, the app uses icon from meta artifact.
        attr_accessor :icon_uri
        
        # UESURI of the entity type of the app (see @{cz.ues.platform.sysc.entitytype.UESEntityType} for more info).
        attr_accessor :entity_type_uri
        
        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        def company_uri
          attributes[:companyUri]
        end

        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def artifact_type
          attributes[:artifactType]
        end

        def artifact_type=(val)
          attributes[:artifactType] = val
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        # @deprecated Use {#version} instead.
        def revision
          attributes[:version]
        end

        # @deprecated Use {#version=} instead.
        def revision=(val)
          attributes[:version] = val
        end

        def version 
          attributes[:version]
        end

        def version=(val) 
          attributes[:version] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end
        
        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end
        
        def app_box_uri
          attributes[:appBoxUri]
        end

        def app_box_uri=(val)
          if val
            attributes[:appBoxUri] = UU::OS::UESURI.new(val)
          else
            attributes[:appBoxUri] = nil
          end
        end

      end
    end

  end
end
